Cholla 3.0.1-dev
Cholla - Massively parallel hydro on GPUs
Loading...
Searching...
No Matches
Functions | Variables
plm_cuda.cu File Reference

Definitions of the piecewise linear reconstruction functions, as described in Stone et al., 2008. More...

#include <math.h>
#include "../global/global.h"
#include "../global/global_cuda.h"
#include "../reconstruction/plm_cuda.h"
#include "../utils/cuda_utilities.h"
#include "../utils/gpu.hpp"
Include dependency graph for plm_cuda.cu:

Functions

template<int dir>
__global__ __launch_bounds__ (TPB) void PLM_cuda(Real *dev_conserved
 
 if (reconstruction::Thread_Guard< 2 >(nx, ny, nz, xid, yid, zid))
 
if constexpr (dir==0)
 
template __global__ __launch_bounds__ (TPB) void PLM_cuda< 0 >(Real *dev_conserved
 

Variables

__global__ Real * dev_bounds_L
 
__global__ Real Real * dev_bounds_R
 
__global__ Real Real int nx
 
__global__ Real Real int int ny
 
__global__ Real Real int int int nz
 
__global__ Real Real int int int Real dx
 
__global__ Real Real int int int Real Real dt
 
__global__ Real Real int int int Real Real Real gamma
 
int xid
 
int yid
 
int zid
 
 auto [interface_L_iph, interface_R_imh]
 
int o1
 
int o2
 
int o3
 
int const n_cells = nx * ny * nz
 
size_t id = cuda_utilities::compute1DIndex(xid, yid, zid, nx, ny)
 

Detailed Description

Definitions of the piecewise linear reconstruction functions, as described in Stone et al., 2008.

Variable Documentation

◆ auto

auto[interface_L_iph, interface_R_imh]
Initial value:
=
reconstruction::PLM_Reconstruction<dir>(dev_conserved, xid, yid, zid, nx, ny, nz, dx, dt, gamma)

◆ gamma

template __global__ Real Real int int int Real gamma
Initial value:
{
int const thread_id = threadIdx.x + blockIdx.x * blockDim.x